@@ -23,7 +23,7 @@
 #ifndef MODUTILS_MODULE_H
 #define MODUTILS_MODULE_H 1
 
-#ident "$Id: module.h,v 1.4 1998/05/20 15:07:49 jj Exp $"
+#ident "$Id: module.h 1.1 Tue, 24 Aug 1999 23:26:49 -0700 keith $"
 
 /* This file contains the structures used by the 2.0 and 2.1 kernels.
    We do not use the kernel headers directly because we do not wish
@@ -112,23 +112,23 @@ int old_sys_init_module(const char *name, char *code, unsigned codesize,
 /*======================================================================*/
 /* The structures used in Linux 2.1.  */
 
-/* Note: new_module_symbol does not use tgt_long intentionally */
-struct new_module_symbol
+/* Note: module_symbol does not use tgt_long intentionally */
+struct module_symbol
 {
   unsigned long value;
   unsigned long name;
 };
 
-struct new_module_persist;
+struct module_persist;
 
-struct new_module_ref
+struct module_ref
 {
   unsigned tgt_long dep;		/* kernel addresses */
   unsigned tgt_long ref;
   unsigned tgt_long next_ref;
 };
 
-struct new_module
+struct module
 {
   unsigned tgt_long size_of_struct;	/* == sizeof(module) */
   unsigned tgt_long next;
@@ -158,7 +158,7 @@ struct new_module
   unsigned tgt_long runsize;
 };
 
-struct new_module_info
+struct module_info
 {
   unsigned long addr;
   unsigned long size;
@@ -173,7 +173,7 @@ struct new_module_info
 #define NEW_MOD_VISITED		8
 #define NEW_MOD_USED_ONCE	16
 
-int new_sys_init_module(const char *name, const struct new_module *);
+int sys_init_module(const char *name, const struct module *);
 int query_module(const char *name, int which, void *buf, size_t bufsize,
 		 size_t *ret);
 
