@@ -24,9 +24,11 @@
 /*
  * Blocking/unblocking of SIGCHLD due to: Eduardo Blanco <ejbs@cs.cs.com.uy>
  * Better error reports by: Lars Fenneberg <in5y050@public.uni-hamburg.de>
+ * memmove instead of memcpy: Ton Nijkes <tonn@wau.mis.ah.nl>
+ * Kerneld warnings: Steve Dodd <dirk@loth.demon.co.uk>
  */
 
-#ident "$Id: kerneld.c,v 1.3 1998/04/25 20:02:43 rth Exp $"
+#ident "$Id: kerneld.c 1.1 Tue, 24 Aug 1999 23:26:49 -0700 keith $"
 
 #define CONFIG_KERNELD
 #include <stdio.h>
@@ -156,9 +158,11 @@ void gdbm_reload(int dummy)
 		gdbm_close(dbf);
 	}
 #endif
+#ifndef NO_ROUTE
 	if (access(REQUEST_ROUTE, X_OK) == 0)
 		have_request_route = 1;
 	else
+#endif
 		have_request_route = 0;
 }
 
@@ -204,7 +208,7 @@ int do_msgsnd(int msqid, struct kerneld_msg *msg, size_t msgsz, int msgflg)
 		if (msgsz) {
 			struct oldkerneld_msg *omsg =
 				(struct oldkerneld_msg *)msg;
-			memcpy(omsg->text, msg->text, msgsz);
+			memmove(omsg->text, msg->text, msgsz);
 		}
 	}
 	else
@@ -225,8 +229,9 @@ int do_msgrcv(int msqid, struct kerneld_msg *msg, size_t msgsz, long msgtyp, int
 		if (msg->version != 2) {
 			struct oldkerneld_msg *omsg =
 				(struct oldkerneld_msg *)msg;
-			memcpy(msg->text, omsg->text, sz);
+			memmove(msg->text, omsg->text, sz);
 			msg->pid = msg->version = 0;
+			sz += sizeof(short int) + sizeof(short int);
 		}
 	}
 #endif
@@ -778,6 +783,31 @@ main(int argc, char *argv[])
 	struct sigaction sa;
 	sigset_t hold_signals;
 
+	uname(&uts_info);
+
+#ifdef NEW_KERNELD_PROTOCOL
+	if (uts_info.release[0] < '2' ||
+	    (uts_info.release[0] == '2' && uts_info.release[2] == '0')) {
+		printf("kerneld: warning, "
+			"kerneld compiled with NEW_KERNELD_PROTOCOL "
+			"running on\n\t kernel <= 2.0; "
+			"may well not work correctly.\n" );
+	}
+#endif
+
+	if (uts_info.release[0] == '2' && uts_info.release[2] == '1') {
+		printf("kerneld: hmm, no idea whether this version "
+			"of kerneld will work with your 2.1.x kernel.\n"
+			"Upgrade to 2.2.x?\n");
+}
+
+	if (uts_info.release[0] > '2' ||
+	    (uts_info.release[0] == '2' && uts_info.release[2] > '1') ) {
+		printf("kerneld: you almost certainly don't want to be running "
+			"kerneld with >= 2.2.x\n\t kernels; "
+			"read /usr/src/linux/Documentation/kmod.txt.\n");
+	}
+
 	/* make me a daemon */
 	if ((pid = fork()) != 0) {
 		printf("Starting kerneld, version " MODUTILS_VERSION " (pid %d)\n", pid);
