@@ -19,7 +19,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: obj_alpha.c,v 1.1 1997/09/10 22:20:02 rth Exp $"
+#ident "$Id: obj_alpha.c 1.1 Tue, 24 Aug 1999 23:26:49 -0700 keith $"
 
 #include <string.h>
 #include <assert.h>
@@ -77,6 +77,16 @@ arch_new_symbol (void)
   return &sym->root;
 }
 
+int
+arch_load_proc_section(struct obj_section *sec, FILE *fp)
+{
+    /* Assume it's just a debugging section that we can safely
+       ignore ...  */
+    sec->contents = NULL;
+
+    return 0;
+}
+
 enum obj_reloc
 arch_apply_relocation (struct obj_file *f,
 		       struct obj_section *targsec,
@@ -268,7 +278,7 @@ arch_create_got (struct obj_file *f)
 }
 
 int
-arch_init_module (struct obj_file *f, struct new_module *mod)
+arch_init_module (struct obj_file *f, struct module *mod)
 {
   struct alpha_file *af = (struct alpha_file *)f;
 
