@@ -19,6 +19,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
+#ident "$Id: obj_m68k.c 1.1 Tue, 24 Aug 1999 23:26:49 -0700 keith $"
 
 #include <stddef.h>
 #include <module.h>
@@ -46,6 +47,15 @@ arch_new_symbol (void)
   return xmalloc(sizeof(struct obj_symbol));
 }
 
+int
+arch_load_proc_section(struct obj_section *sec, FILE *fp)
+{
+    /* Assume it's just a debugging section that we can safely
+       ignore ...  */
+    sec->contents = NULL;
+
+    return 0;
+}
 
 enum obj_reloc
 arch_apply_relocation (struct obj_file *ef,
@@ -114,7 +124,7 @@ arch_create_got (struct obj_file *ef)
 }
 
 int
-arch_init_module (struct obj_file *f, struct new_module *mod)
+arch_init_module (struct obj_file *f, struct module *mod)
 {
   return 1;
 }
