@@ -18,7 +18,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ident "$Id: obj_mips.c,v 1.2 1998/07/31 22:38:44 rth Exp $"
+#ident "$Id: obj_mips.c 1.1 Tue, 24 Aug 1999 23:26:49 -0700 keith $"
 
 #include <string.h>
 #include <stdlib.h>
@@ -41,21 +41,20 @@ struct mips_hi16
 struct mips_file
 {
   struct obj_file root;
-  struct obj_section *got;
   struct mips_hi16 *mips_hi16_list;
 };
 
-struct mips_symbol
-{
-  struct obj_symbol root;
-};
-
 /*======================================================================*/
 
 struct obj_file *
 arch_new_file (void)
 {
-  return xmalloc(sizeof(struct obj_file));
+  struct mips_file *mf;
+
+  mf = xmalloc(sizeof(*mf));
+  mf->mips_hi16_list = NULL;
+
+  return (struct obj_file *) mf;
 }
 
 struct obj_section *
@@ -67,7 +66,7 @@ arch_new_section (void)
 struct obj_symbol *
 arch_new_symbol (void)
 {
-  return xmalloc(sizeof(struct obj_section));
+  return xmalloc(sizeof(struct obj_symbol));
 }
 
 int
@@ -78,19 +77,9 @@ arch_load_proc_section(struct obj_section *sec, FILE *fp)
     case SHT_MIPS_DEBUG:
     case SHT_MIPS_REGINFO:
       /* Actually these two sections are as useless as something can be ...  */
-      if (sec->header.sh_size > 0)
-	{
-	  sec->contents = xmalloc(sec->header.sh_size);
-	  fseek(fp, sec->header.sh_offset, SEEK_SET);
-	  if (fread(sec->contents, sec->header.sh_size, 1, fp) != 1)
-	  {
-	    error("error reading ELF section data: %m");
-	    return -1;
-	  }
-	}
-      else
-	sec->contents = NULL;
+      sec->contents = NULL;
       break;
+
     case SHT_MIPS_LIBLIST:
     case SHT_MIPS_CONFLICT:
     case SHT_MIPS_GPTAB:
@@ -98,14 +87,13 @@ arch_load_proc_section(struct obj_section *sec, FILE *fp)
     case SHT_MIPS_OPTIONS:
     case SHT_MIPS_DWARF:
     case SHT_MIPS_EVENTS:
-      /* We don't even attempt to handle these.  Expect your kernel to
-         turn into a nova.  */
-      error("Unhandled section header type: %m");
-      return -1;
+      /* These shouldn't ever be in a module file.  */
+      error("Unhandled section header type: %08x", sec->header.sh_type);
+
     default:
       /* We don't even know the type.  This time it might as well be a
 	 supernova.  */
-      error("Unknown section header type: %m");
+      error("Unknown section header type: %08x", sec->header.sh_type);
       return -1;
     }
 
@@ -144,7 +132,7 @@ arch_apply_relocation (struct obj_file *f,
         ret = obj_reloc_dangerous;
       if ((v & 0xf0000000) != (dot & 0xf0000000))
 	ret = obj_reloc_overflow;
-      *loc = (*loc & ~0x03ffffff) | ((*loc & 0x03ffffff) + (v >> 2));
+      *loc = (*loc & ~0x03ffffff) | ((*loc + (v >> 2)) & 0x03ffffff);
       break;
 
     case R_MIPS_HI16:
@@ -227,7 +215,7 @@ arch_create_got (struct obj_file *f)
 }
 
 int
-arch_init_module (struct obj_file *f, struct new_module *mod)
+arch_init_module (struct obj_file *f, struct module *mod)
 {
   return 1;
 }
